@@ -15,6 +15,7 @@ except ImportError:
     from urllib.parse import urlencode
 import logging
 from owslib.util import log
+from owslib.feature.schema import get_schema
 
 class WebFeatureService_(object):
     """Base class for WebFeatureService implementations"""
@@ -127,13 +128,19 @@ class WebFeatureService_(object):
             request['query'] = str(filter)
         if typename:
             typename = [typename] if type(typename) == type("") else typename
-            request['typename'] = ','.join(typename)
+            if int(self.version.split('.')[0]) >= 2:
+                request['typenames'] = ','.join(typename)
+            else:
+                request['typename'] = ','.join(typename)
         if propertyname: 
             request['propertyname'] = ','.join(propertyname)
         if featureversion: 
             request['featureversion'] = str(featureversion)
         if maxfeatures: 
-            request['maxfeatures'] = str(maxfeatures)
+            if int(self.version.split('.')[0]) >= 2:
+                request['count'] = str(maxfeatures)
+            else:
+                request['maxfeatures'] = str(maxfeatures)
         if startindex:
             request['startindex'] = str(startindex)
         if storedQueryID: 
@@ -146,3 +153,13 @@ class WebFeatureService_(object):
         data = urlencode(request)
 
         return base_url+data
+
+
+    def get_schema(self, typename):
+        """
+        Get layer schema compatible with :class:`fiona` schema object
+        """
+
+        return get_schema(self.url, typename, self.version)
+    
+
