@@ -69,9 +69,13 @@ class ServiceIdentification(object):
         val = self._root.find(util.nspath('ServiceTypeVersion', namespace))
         self.version = util.testXMLValue(val)
 
+        self.versions = []
+        for v in self._root.findall(util.nspath('ServiceTypeVersion', namespace)):
+            self.versions.append(util.testXMLValue(v))
+        
         self.profiles = []
         for p in self._root.findall(util.nspath('Profile', namespace)):
-            self.profiles.append(util.testXMLValue(val))
+            self.profiles.append(util.testXMLValue(p))
 
 class ServiceProvider(object):
     """Initialize an OWS Common ServiceProvider construct"""
@@ -161,6 +165,19 @@ class Constraint(object):
             return "Constraint: %s" % self.name
 
 
+class Parameter(object):
+    def __init__(self, elem, namespace=DEFAULT_OWS_NAMESPACE):
+        self.name    = elem.attrib.get('name')
+        self.values  = [i.text for i in elem.findall(util.nspath('Value', namespace))]
+        self.values += [i.text for i in elem.findall(util.nspath('AllowedValues/Value', namespace))]
+
+    def __repr__(self):
+        if self.values:
+            return "Parameter: %s - %s" % (self.name, self.values)
+        else:
+            return "Parameter: %s" % self.name
+
+
 class OperationsMetadata(object):
     """Initialize an OWS OperationMetadata construct"""
     def __init__(self, elem, namespace=DEFAULT_OWS_NAMESPACE):
