@@ -1,7 +1,12 @@
+from __future__ import (absolute_import, division, print_function)
+
 import cgi
 from owslib.etree import etree
 from datetime import datetime
-from urllib import urlencode
+try:                    # Python 3
+    from urllib.parse import urlencode
+except ImportError:     # Python 2
+    from urllib import urlencode
 from owslib import ows
 from owslib.crs import Crs
 from owslib.fes import FilterCapabilities
@@ -10,7 +15,7 @@ from owslib.namespaces import Namespaces
 
 def get_namespaces():
     n = Namespaces()
-    ns = n.get_namespaces(["ogc","sml","gml","om","sos","swe","xlink"])
+    ns = n.get_namespaces(["ogc","sa","sml","gml","sos","swe","xlink"])
     ns["ows"] = n.get_namespace("ows110")
     return ns
 namespaces = get_namespaces()
@@ -33,7 +38,7 @@ class SensorObservationService_1_0_0(object):
         if id in self.__getattribute__('contents').keys():
             return self.__getattribute__('contents')[id]
         else:
-            raise KeyError, "No Observational Offering with id: %s" % id
+            raise KeyError("No Observational Offering with id: %s" % id)
 
     def __init__(self, url, version='1.0.0', xml=None, username=None, password=None):
         """Initialize."""
@@ -70,6 +75,9 @@ class SensorObservationService_1_0_0(object):
         """
             Set up capabilities metadata objects
         """
+
+        self.updateSequence = self._capabilities.attrib.get('updateSequence')
+
         # ows:ServiceIdentification metadata
         service_id_element = self._capabilities.find(nspath_eval('ows:ServiceIdentification', namespaces))
         self.identification = ows.ServiceIdentification(service_id_element)
@@ -143,6 +151,7 @@ class SensorObservationService_1_0_0(object):
                                 offerings=None,
                                 observedProperties=None,
                                 eventTime=None,
+                                procedure=None,
                                 method='Get',
                                 **kwargs):
         """
@@ -181,13 +190,17 @@ class SensorObservationService_1_0_0(object):
         if 'timeout' in kwargs:
             url_kwargs['timeout'] = kwargs.pop('timeout') # Client specified timeout value
 
+        if procedure is not None:
+            request['procedure'] = procedure
+
         if kwargs:
             for kw in kwargs:
                 request[kw]=kwargs[kw]
 
         data = urlencode(request)
 
-        response = openURL(base_url, data, method, username=self.username, password=self.password, **kwargs).read()
+        response = openURL(base_url, data, method, username=self.username,
+                           password=self.password, **url_kwargs).read()
         try:
             tr = etree.fromstring(response)
             if tr.tag == nspath_eval("ows:ExceptionReport", namespaces):
@@ -206,7 +219,7 @@ class SensorObservationService_1_0_0(object):
         for item in self.operations:
             if item.name.lower() == name.lower():
                 return item
-        raise KeyError, "No Operation named %s" % name
+        raise KeyError("No Operation named %s" % name)
 
 class SosObservationOffering(object):
     def __init__(self, element):
@@ -228,7 +241,7 @@ class SosObservationOffering(object):
             # (left, bottom, right, top) in self.bbox_srs units
             self.bbox = (float(lower_left_corner[1]), float(lower_left_corner[0]), float(upper_right_corner[1]), float(upper_right_corner[0]))
             self.bbox_srs = Crs(testXMLValue(envelope.attrib.get('srsName'), True))
-        except Exception, err:
+        except Exception:
             self.bbox = None
             self.bbox_srs = None
 
@@ -267,6 +280,9 @@ class SosObservationOffering(object):
     def __str__(self):
         return 'Offering id: %s, name: %s' % (self.id, self.name)
 
+    def __repr__(self):
+        return "<SosObservationOffering '%s'>" % self.name
+
 class SosCapabilitiesReader(object):
     def __init__(self, version="1.0.0", url=None, username=None, password=None):
         self.version = version
@@ -313,6 +329,6 @@ class SosCapabilitiesReader(object):
 
             st should be an XML capabilities document
         """
-        if not isinstance(st, str):
-            raise ValueError("String must be of type string, not %s" % type(st))
+        if not isinstance(st, bytes):
+            raise ValueError("String must be of type bytes, not %s" % type(st))
         return etree.fromstring(st)
